@@ -34,7 +34,7 @@ class ConnectionStatus(Enum):
     DISCONNECTED_FROM_BROKER = 'DISCONNECTED_FROM_BROKER'
 
 
-class AccountsFilter(TypedDict):
+class AccountsFilter(TypedDict, total=False):
 
     offset: Optional[int]
     """Search offset (defaults to 0) (must be greater or equal to 0)."""
@@ -61,7 +61,7 @@ class MetatraderAccountIdDto(TypedDict):
     """MetaTrader account unique identifier"""
 
 
-class MetatraderAccountDto(TypedDict):
+class MetatraderAccountDto(TypedDict, total=False):
     """MetaTrader account model"""
 
     _id: str
@@ -76,7 +76,7 @@ class MetatraderAccountDto(TypedDict):
     """MetaTrader server which hosts the account."""
     version: int
     """MT version (allowed values are 4 and 5)."""
-    provisioningProfileId: str
+    provisioningProfileId: Optional[str]
     """Id of the account's provisioning profile."""
     application: str
     """Application name to connect the account to. Currently allowed values are MetaApi and AgiliumTrade"""
@@ -123,7 +123,7 @@ class MetatraderAccountDto(TypedDict):
     Default is 1."""
 
 
-class NewMetatraderAccountDto(TypedDict):
+class NewMetatraderAccountDto(TypedDict, total=False):
     """New MetaTrader account model"""
 
     name: str
@@ -139,7 +139,9 @@ class NewMetatraderAccountDto(TypedDict):
     password to enable trading features. Required for cloud account."""
     server: str
     """MetaTrader server which hosts the account."""
-    provisioningProfileId: str
+    platform: Optional[str]
+    """Platform id (mt4 or mt5)"""
+    provisioningProfileId: Optional[str]
     """Id of the account's provisioning profile."""
     application: str
     """Application name to connect the account to. Currently allowed values are MetaApi and AgiliumTrade."""
@@ -171,7 +173,7 @@ class NewMetatraderAccountDto(TypedDict):
     note that allocating extra resource slots is a paid option. Default is 1."""
 
 
-class MetatraderAccountUpdateDto(TypedDict):
+class MetatraderAccountUpdateDto(TypedDict, total=False):
     """Updated MetaTrader account data"""
 
     name: str
