@@ -229,7 +229,8 @@ class TestSyncStability:
     async def test_sync(self):
         """Should synchronize account"""
         account = await api.metatrader_account_api.get_account('accountId')
-        connection = await account.get_streaming_connection()
+        connection = account.get_streaming_connection()
+        await connection.connect()
         await connection.wait_synchronized({'timeoutInSeconds': 10})
         response = connection.terminal_state.account_information
         assert response == account_information
@@ -241,7 +242,8 @@ class TestSyncStability:
         """Should reconnect on server socket crash."""
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 10})
             await sio.disconnect(client_sid)
             await sleep(0.5)
@@ -255,7 +257,8 @@ class TestSyncStability:
         """Should set state to disconnected on timeout."""
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 10})
             fake_server.delete_status_task('accountId')
 
@@ -274,7 +277,8 @@ class TestSyncStability:
         """Should resubscribe on timeout."""
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 10})
             fake_server.status_tasks['accountId'].cancel()
             await sleep(1.5)
@@ -305,7 +309,8 @@ class TestSyncStability:
                 await fake_server.respond_account_information(data)
 
         account = await api.metatrader_account_api.get_account('accountId')
-        connection = await account.get_streaming_connection()
+        connection = account.get_streaming_connection()
+        await connection.connect()
         await connection.wait_synchronized({'timeoutInSeconds': 10})
         response = connection.terminal_state.account_information
         assert response == account_information
@@ -317,7 +322,8 @@ class TestSyncStability:
         """Should wait until account is redeployed after disconnect."""
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 10})
             fake_server.delete_status_task('accountId')
             fake_server.disable_sync()
@@ -343,7 +349,8 @@ class TestSyncStability:
         """Should resubscribe immediately after disconnect on status packet."""
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 10})
             fake_server.delete_status_task('accountId')
             await sio.emit('synchronization', {'type': 'disconnected', 'accountId': 'accountId',
@@ -365,13 +372,16 @@ class TestSyncStability:
         """Should resubscribe other accounts after one of connections is closed"""
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 10})
             account2 = await api.metatrader_account_api.get_account('accountId2')
-            connection2 = await account2.get_streaming_connection()
+            connection2 = account2.get_streaming_connection()
+            await connection2.connect()
             await connection2.wait_synchronized({'timeoutInSeconds': 10})
             account3 = await api.metatrader_account_api.get_account('accountId3')
-            connection3 = await account3.get_streaming_connection()
+            connection3 = account3.get_streaming_connection()
+            await connection3.connect()
             await connection3.wait_synchronized({'timeoutInSeconds': 10})
             await connection.close()
             fake_server.delete_status_task('accountId2')
@@ -419,13 +429,16 @@ class TestSyncStability:
 
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 3})
             account2 = await api.metatrader_account_api.get_account('accountId2')
-            connection2 = await account2.get_streaming_connection()
+            connection2 = account2.get_streaming_connection()
+            await connection2.connect()
             await connection2.wait_synchronized({'timeoutInSeconds': 3})
             account3 = await api.metatrader_account_api.get_account('accountId3')
-            connection3 = await account3.get_streaming_connection()
+            connection3 = account3.get_streaming_connection()
+            await connection3.connect()
             try:
                 await connection3.wait_synchronized({'timeoutInSeconds': 3})
                 raise Exception('TimeoutException expected')
@@ -470,13 +483,16 @@ class TestSyncStability:
 
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 3})
             account2 = await api.metatrader_account_api.get_account('accountId2')
-            connection2 = await account2.get_streaming_connection()
+            connection2 = account2.get_streaming_connection()
+            await connection2.connect()
             await connection2.wait_synchronized({'timeoutInSeconds': 3})
             account3 = await api.metatrader_account_api.get_account('accountId3')
-            connection3 = await account3.get_streaming_connection()
+            connection3 = account3.get_streaming_connection()
+            await connection3.connect()
             try:
                 await connection3.wait_synchronized({'timeoutInSeconds': 3})
                 raise Exception('TimeoutException expected')
@@ -518,18 +534,22 @@ class TestSyncStability:
 
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 3})
             account2 = await api.metatrader_account_api.get_account('accountId2')
-            connection2 = await account2.get_streaming_connection()
+            connection2 = account2.get_streaming_connection()
+            await connection2.connect()
             await connection2.wait_synchronized({'timeoutInSeconds': 3})
             account3 = await api.metatrader_account_api.get_account('accountId3')
-            connection3 = await account3.get_streaming_connection()
+            connection3 = account3.get_streaming_connection()
+            await connection3.connect()
             await connection3.wait_synchronized({'timeoutInSeconds': 3})
             assert sid_by_accounts['accountId'] == sid_by_accounts['accountId2'] != sid_by_accounts['accountId3']
             await sleep(2)
             account4 = await api.metatrader_account_api.get_account('accountId4')
-            connection4 = await account4.get_streaming_connection()
+            connection4 = account4.get_streaming_connection()
+            await connection4.connect()
             await connection4.wait_synchronized({'timeoutInSeconds': 3})
             assert sid_by_accounts['accountId'] == sid_by_accounts['accountId4']
 
@@ -563,7 +583,8 @@ class TestSyncStability:
 
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 3})
             assert sids[0] != sids[1]
 
@@ -597,18 +618,22 @@ class TestSyncStability:
 
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 3})
             account2 = await api.metatrader_account_api.get_account('accountId2')
-            connection2 = await account2.get_streaming_connection()
+            connection2 = account2.get_streaming_connection()
+            await connection2.connect()
             await connection2.wait_synchronized({'timeoutInSeconds': 3})
             account3 = await api.metatrader_account_api.get_account('accountId3')
-            connection3 = await account3.get_streaming_connection()
+            connection3 = account3.get_streaming_connection()
+            await connection3.connect()
             await connection3.wait_synchronized({'timeoutInSeconds': 3})
             assert sid_by_accounts['accountId'] == sid_by_accounts['accountId2'] != sid_by_accounts['accountId3']
             await connection2.close()
             account4 = await api.metatrader_account_api.get_account('accountId4')
-            connection4 = await account4.get_streaming_connection()
+            connection4 = account4.get_streaming_connection()
+            await connection4.connect()
             await connection4.wait_synchronized({'timeoutInSeconds': 3})
             assert sid_by_accounts['accountId'] == sid_by_accounts['accountId4']
 
@@ -646,23 +671,28 @@ class TestSyncStability:
 
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 3})
             account2 = await api.metatrader_account_api.get_account('accountId2')
-            connection2 = await account2.get_streaming_connection()
+            connection2 = account2.get_streaming_connection()
+            await connection2.connect()
             await connection2.wait_synchronized({'timeoutInSeconds': 3})
             account3 = await api.metatrader_account_api.get_account('accountId3')
-            connection3 = await account3.get_streaming_connection()
+            connection3 = account3.get_streaming_connection()
+            await connection3.connect()
             await connection3.wait_synchronized({'timeoutInSeconds': 3})
             assert sid_by_accounts['accountId'] == sid_by_accounts['accountId2'] != sid_by_accounts['accountId3']
             await sleep(2)
             account4 = await api.metatrader_account_api.get_account('accountId4')
-            connection4 = await account4.get_streaming_connection()
+            connection4 = account4.get_streaming_connection()
+            await connection4.connect()
             await connection4.wait_synchronized({'timeoutInSeconds': 3})
             assert sid_by_accounts['accountId'] != sid_by_accounts['accountId4']
             await connection2.close()
             account5 = await api.metatrader_account_api.get_account('accountId5')
-            connection5 = await account5.get_streaming_connection()
+            connection5 = account5.get_streaming_connection()
+            await connection5.connect()
             await connection5.wait_synchronized({'timeoutInSeconds': 3})
             assert sid_by_accounts['accountId'] == sid_by_accounts['accountId5']
 
@@ -671,7 +701,8 @@ class TestSyncStability:
         """Should attempt to resubscribe on disconnected packet."""
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 10})
             assert connection.synchronized
             assert connection.terminal_state.connected
@@ -693,7 +724,8 @@ class TestSyncStability:
         """Should handle multiple streams in one instance number."""
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 10})
             subscribe_called = False
 
@@ -733,7 +765,8 @@ class TestSyncStability:
         """Should not resubscribe if multiple streams and one timed out."""
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 10})
             subscribe_called = False
 
@@ -792,11 +825,13 @@ class TestSyncStability:
                 await fake_server.respond(data)
 
         account = await api.metatrader_account_api.get_account('accountId')
-        connection = await account.get_streaming_connection()
+        connection = account.get_streaming_connection()
+        await connection.connect()
         await connection.wait_synchronized({'timeoutInSeconds': 3})
         assert synchronize_counter == 1
         account2 = await api.metatrader_account_api.get_account('accountId2')
-        connection2 = await account2.get_streaming_connection()
+        connection2 = account2.get_streaming_connection()
+        await connection2.connect()
         await sleep(0.1)
         await connection2.close()
         try:
@@ -835,7 +870,8 @@ class TestSyncStability:
                     await fake_server.respond(data)
 
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 10})
             assert connection.synchronized and connection.terminal_state.connected and \
                    connection.terminal_state.connected_to_broker
@@ -861,7 +897,8 @@ class TestSyncStability:
         """Should not resubscribe on timeout if connection is closed."""
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 10})
             fake_server.status_tasks['accountId'].cancel()
             assert connection.synchronized
@@ -875,7 +912,8 @@ class TestSyncStability:
         with patch('lib.clients.metaApi.metaApiWebsocket_client.asyncio.sleep', new=lambda x: sleep(x / 50)):
             subscribe_calls = 0
             account = await api.metatrader_account_api.get_account('accountId')
-            connection = await account.get_streaming_connection()
+            connection = account.get_streaming_connection()
+            await connection.connect()
             await connection.wait_synchronized({'timeoutInSeconds': 10})
             fake_server.disable_sync()
             fake_server.status_tasks['accountId'].cancel()
